@@ -2,8 +2,8 @@ from collections import OrderedDict
 
 import requests
 import six
-from tqdm import tqdm
 from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
+from tqdm import tqdm
 
 
 class ProgressBar(tqdm):
@@ -15,12 +15,34 @@ class ProgressBar(tqdm):
         self.update(n - self.n)
 
 
+PRESERVED_ORDER_V1 = ("policy", "AWSAccessKeyId", "key", "signature")
+PRESERVED_SIGNATURE_V4 = (
+    "key", "success_action_status",
+    "policy", "x-amz-credential", "x-amz-algorithm",
+    "x-amz-date", "x-amz-signature"
+)
+
+
+def _order_upload_keys(fields, keys):
+    output_fields = OrderedDict()
+    for key in keys:
+        if fields.get(key):
+            output_fields[key] = fields[key]
+    return output_fields
+
+
+def format_request_body(fields):
+    if set(fields.keys()).issubset(set(PRESERVED_ORDER_V1)):
+        return _order_upload_keys(fields, PRESERVED_ORDER_V1)
+    elif set(fields.keys()).issubset(set(PRESERVED_SIGNATURE_V4)):
+        return _order_upload_keys(fields, PRESERVED_SIGNATURE_V4)
+    else:
+        return fields
+
+
 def upload(destination, file, progress_bar=False):
     url = destination["url"]
-    fields = OrderedDict()
-
-    for key in ("policy", "AWSAccessKeyId", "key", "signature"):
-        fields[key] = destination["fields"][key]
+    fields = format_request_body(destination['fields'])
 
     fields["file"] = ("features_backup.rcdb", file)
     encoder = MultipartEncoder(fields=fields)
