@@ -101,6 +101,26 @@ def cancel(ctx, processing_ids, concurrency):
     return task_runner(ctx, task_cancel_processing, processing_ids, concurrency)
 
 
+@api.command()
+@click.argument('processing_ids', required=True, nargs=-1, type=click.INT)
+@click.option('-b', '--batch-size', type=int, default=3,
+              help="The lower the number the slower and more reliable the upload will be")
+@pass_rebotics_context
+def export_to_dataset(ctx, processing_ids, batch_size):
+    if ctx.verbose:
+        click.echo("Exporting to dataset with batch size {} scans: {}".format(batch_size, processing_ids), err=True)
+
+    try:
+        if ctx.verbose:
+            click.echo("Sending request...")
+        response = ctx.provider.export_to_dataset(processing_ids, batch_size)
+        click.echo('Queued to export to dataset: {}'.format(response))
+    except ProviderHTTPClientException as exc:
+        if ctx.verbose:
+            logger.exception(exc)
+        raise click.ClickException(str(exc.response.json()))
+
+
 @api.command()
 @click.argument('processing_ids', required=True, nargs=-1, type=click.INT)
 @click.option('-c', '--concurrency', type=int, default=4)
@@ -312,7 +332,9 @@ def processing_actions(ctx, store, status, page, page_size):
         if ctx.format != 'id':
             format_processing_action_output(data, 'id')
         format_processing_action_output(data, ctx.format)
-    except ProviderHTTPClientException:
+    except ProviderHTTPClientException as exc:
+        if ctx.verbose:
+            logger.exception(exc)
         raise click.ClickException('Failed to get list of processing actions')
 
 
