@@ -405,3 +405,10 @@ class RetailerProvider(ReboticsBaseProvider):
     def get_spacial_data(self, scan_id):
         """Can yield permission error. Internal usage intended"""
         return self.session.get(id=scan_id)
+
+    @remote_service('api/v4/processing/actions/export-to-dataset/')
+    def export_to_dataset(self, scan_ids, batch_size=5):
+        return self.session.post(json={
+            'scans': sorted(list(set(scan_ids))),
+            'batch_size': batch_size,
+        })
